@@ -71,8 +71,11 @@ on_adjustment_value_changed (GtkAdjustment *adjustment,
 
         volume = gtk_adjustment_get_value (adjustment);
 
-        gvc_mixer_stream_set_volume(icon->priv->mixer_stream,
-                                    (pa_volume_t) volume);
+        /* Only push the volume if it's actually changed */
+        if (gvc_mixer_stream_set_volume(icon->priv->mixer_stream,
+                                    (pa_volume_t) round (volume)) != FALSE) {
+                gvc_mixer_stream_push_volume(icon->priv->mixer_stream);
+        }
 }
 
 static void
@@ -169,7 +172,7 @@ popup_dock (GvcStreamStatusIcon *icon,
         /* grab focus */
         gtk_grab_add (icon->priv->dock);
 
-        if (gdk_pointer_grab (icon->priv->dock->window, TRUE,
+        if (gdk_pointer_grab (gtk_widget_get_window (icon->priv->dock), TRUE,
                               GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
                               GDK_POINTER_MOTION_MASK | GDK_SCROLL_MASK, NULL, NULL,
                               time)
@@ -179,7 +182,7 @@ popup_dock (GvcStreamStatusIcon *icon,
                 return FALSE;
         }
 
-        if (gdk_keyboard_grab (icon->priv->dock->window, TRUE, time) != GDK_GRAB_SUCCESS) {
+        if (gdk_keyboard_grab (gtk_widget_get_window (icon->priv->dock), TRUE, time) != GDK_GRAB_SUCCESS) {
                 display = gtk_widget_get_display (icon->priv->dock);
                 gdk_display_pointer_ungrab (display, time);
                 gtk_grab_remove (icon->priv->dock);
@@ -340,7 +343,7 @@ gvc_icon_grab_notify (GvcStreamStatusIcon *icon,
                 return;
         }
 
-        if (!GTK_WIDGET_HAS_GRAB (icon->priv->dock)) {
+        if (!gtk_widget_has_grab (icon->priv->dock)) {
                 return;
         }
 
@@ -538,9 +541,11 @@ gvc_stream_status_icon_set_mixer_stream (GvcStreamStatusIcon *icon,
 
                 g_object_ref (icon->priv->mixer_stream);
 
+                icon->priv->thaw = TRUE;
                 adj = GTK_ADJUSTMENT (gvc_channel_bar_get_adjustment (GVC_CHANNEL_BAR (icon->priv->bar)));
                 gtk_adjustment_set_value (adj,
                                           gvc_mixer_stream_get_volume (icon->priv->mixer_stream));
+                icon->priv->thaw = FALSE;
 
                 g_signal_connect (icon->priv->mixer_stream,
                                   "notify::volume",
@@ -614,8 +619,13 @@ on_bar_is_muted_notify (GObject             *object,
         gboolean is_muted;
 
         is_muted = gvc_channel_bar_get_is_muted (GVC_CHANNEL_BAR (object));
-        gvc_mixer_stream_change_is_muted (icon->priv->mixer_stream,
-                                          is_muted);
+
+        if (gvc_mixer_stream_get_is_muted (icon->priv->mixer_stream) != is_muted) {
+                /* Update the stream before pushing the change */
+                gvc_mixer_stream_set_is_muted (icon->priv->mixer_stream, is_muted);
+                gvc_mixer_stream_change_is_muted (icon->priv->mixer_stream,
+                                                  is_muted);
+        }
 }
 
 static GObject *
